pitchtools.PitchRangeInventory
==============================

.. inheritance-diagram:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.name

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.append

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.extend

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__contains__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__repr__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.pitchtools.PitchRangeInventory.PitchRangeInventory.PitchRangeInventory.__setslice__

    Inherited from :py:class:`__builtin__.list`
